@@ -85,12 +85,25 @@ class EditCourses(object):
 				
 	def add_course(self):
 		course = raw_input("Type the name of your course: ")
-			
-		units = raw_input("How many units is this course? ")
-		user_data[course + "_units"] = units
 		
-		grade = int(raw_input("What is your percentage grade in this course? (Omit the '%'): "))
-		user_data[course + "_grade"] = grade
+		while True:
+			try:
+				units = int(raw_input("How many units is this course? "))
+				user_data[course + "_units"] = units
+				break
+
+			except ValueError:
+				print "Please enter a valid number of units."
+				
+		while True:
+			try:
+				grade = int(raw_input("What is your percentage grade in this course? (Omit the '%'): "))
+				user_data[course + "_grade"] = grade
+				break
+
+			except ValueError:
+				print "Please enter a valid percentage."
+			
 
 	def del_course(self):
 		Display().display_grades()
@@ -137,7 +150,13 @@ class User(EditCourses):
 		username = raw_input("Please enter your name: ")
 		user_data["name"] = username
 
-		number_of_courses = int(raw_input("Please enter the number of courses you are currently taking: "))
+		while True:
+			try:
+				number_of_courses = int(raw_input("Please enter the number of courses you are currently taking: "))
+				break
+
+			except ValueError:
+				print "Please enter a valid number of courses."
 		
 		for course_num in range(number_of_courses):
 			User().add_course()
@@ -153,6 +172,8 @@ class User(EditCourses):
 				with open(name + ".txt") as file_name:
 					global user_data
 					user_data = json.load(file_name)
+				break
+
 			except IOError:
 				print "User \"%s\" does not exist." % name
 
@@ -324,5 +345,3 @@ class Required(object):
 		
 		raw_input("\nPress ENTER to return to the Main Menu: ")
 		MainMenu(username).menu(username)
-
-Initialize().new_or_existing()
